#ifndef __PFE_DEF_XTRA_H
#define __PFE_DEF_XTRA_H "%full_filespec: def-xtra.h~bln_mpt1!33.19:incl:bln_12xx!1 %"

/** 
 * -- declare extras for specific environments
 * 
 *  Copyright (C) Tektronix, Inc. 1998 - 2003. All rights reserved.
 *
 *  @see     GNU LGPL
 *  @author  Tektronix CTE             @(#) %derived_by: guidod %
 *  @version %version: bln_mpt1!33.19 %
 *    (%date_modified: Tue Sep 10 12:30:04 2002 %)
 *  @description
 *            
 */
/*@{*/

#include <pfe/pfe-sub.h>

#ifndef FILE
#include <stdio.h>
#endif

#ifdef _P4_SOURCE
# if defined VxWorks || defined HOST_OS_VXWORKS || defined __target_os_vxworks

# ifndef PFE_HAVE_STRDUP
  extern char *strdup (const char *s);
# endif
# ifndef PFE_HAVE_ACCESS
  extern int access (const char *, int);
# endif
  /* extern int chdir (const char *); */
  extern int close (int);
  /* extern int rmdir (const char *); */

# include <fcntl.h>
# include <timers.h>
# endif /* VxWorks */

#endif

/*@}*/
#endif
